awsapilib.sso.entities package
==============================

Submodules
----------

awsapilib.sso.entities.entities module
--------------------------------------

.. automodule:: awsapilib.sso.entities.entities
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: awsapilib.sso.entities
   :members:
   :undoc-members:
   :show-inheritance:
